@@ -1,13 +1,13 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "ol-notmuch" "2.1.3"
+(define-package "ol-notmuch" "20251101.2058"
   "Links to notmuch messages."
   '((emacs   "29.1")
     (compat  "30.1")
-    (notmuch "0.39")
+    (notmuch "0.38")
     (org     "9.7"))
   :url "https://github.com/tarsius/ol-notmuch"
-  :commit "8f717329388935538fe433b9a15f1599edd9fcd5"
-  :revdesc "v2.1.3-0-g8f7173293889"
+  :commit "7655f5ea25ea40b7d0453ae6531cae59e5ea592f"
+  :revdesc "7655f5ea25ea"
   :keywords '("hypermedia" "mail")
   :authors '(("Matthieu Lemerre" . "racin@free.fr"))
   :maintainers '(("Jonas Bernoulli" . "emacs.ol-notmuch@jonas.bernoulli.dev")))
